camelot.camelot.model.synchronization

Package camelot :: Package camelot :: Package model :: Module synchronization |
[hide private]
[frames] | no frames]

# Source Code for Module camelot.camelot.model.synchronization

     1  #  ==================================================================================
     2  #
     3  #  Copyright (C) 2007-2008 Conceptive Engineering bvba. All rights reserved.
     4  #  www.conceptive.be / project-camelot@conceptive.be
     5  #
     6  #  This file is part of the Camelot Library.
     7  #
     8  #  This file may be used under the terms of the GNU General Public
     9  #  License version 2.0 as published by the Free Software Foundation
    10  #  and appearing in the file LICENSE.GPL included in the packaging of
    11  #  this file.  Please review the following information to ensure GNU
    12  #  General Public Licensing requirements will be met:
    13  #  http://www.trolltech.com/products/qt/opensource.html
    14  #
    15  #  If you are unsure which license is appropriate for your use, please
    16  #  review the following information:
    17  #  http://www.trolltech.com/products/qt/licensing.html or contact
    18  #  project-camelot@conceptive.be.
    19  #
    20  #  This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
    21  #  WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
    22  #
    23  #  For use of this library in commercial applications, please contact
    24  #  project-camelot@conceptive.be
    25  #
    26  #  ==================================================================================
    27  """Functionallity to synchronize elements from the camelot database against
    28  other databases
    29  """
    30
    31  from camelot.model import *
    32  from elixir.ext.associable import *
    33
    34  __metadata__ = metadata
    35
    36  from camelot.view.elixir_admin import EntityAdmin
    37  import datetime
    38
    39 -class Synchronized(Entity):
    40    using_options(tablename='synchronized')
    41    database = Field(Unicode(30), index=True)
    42    tablename = Field(Unicode(30), index=True)
    43    primary_key = Field(Integer(), index=True)
    44    last_update = Field(DateTime(), index=True, default=datetime.datetime.now, onupdate=datetime.datetime.now)
    45
    46  is_synchronized = associable(Synchronized)
    47